require Orgy.libpath(*%w[orgy org_data])

module Orgy
  # ===OrgTimeRange
  # {org-mode time ranges}[http://orgmode.org/manual/Timestamps.html#index-ranges_002c-time-752]
  # Contains two OrgTimeStamps and will print out as an org-mode date/time range.
  class OrgTimeRange 

    # Requires two arguments. Argument one and two are the starting and ending dates respectively.
    # Arguments must be kind of DateTime or Orgy::OrgTimeStamp
    def initialize date_one, date_two

      if date_one.class != Orgy::OrgTimeStamp then
        if date_one.class != DateTime then
        raise ArgumentError, "Argument must be a kind of Orgy::OrgTimeStamp or DateTime"
        end
      end

      if date_two.class != Orgy::OrgTimeStamp then
        if date_two.class != DateTime then
          raise ArgumentError, "Argument must be a kind of Orgy::OrgTimeStamp or DateTime"
        end
      end

      if date_one.class == DateTime then
        date_one = Orgy::OrgTimeStamp.new date_one
      end

      if date_two.class == DateTime then
        date_two = Orgy::OrgTimeStamp.new date_two
      end

      @data = Hash.new
      @data[:starting_date] = date_one
      @data[:ending_date] = date_two
    end

    # Tests to see if the range is active
    def active?
      @data[:starting_date].active? or @data[:ending_date].active?
    end

    # Declares the range as active
    def active!
      @data[:starting_date].active!
      @data[:ending_date].active!
    end

    # Declares the range as inactive
    def inactive!
      @data[:starting_date].inactive!
      @data[:ending_date].inactive!
    end

    # Prints range to string
    def to_s
      if active? then active! else inactive! end                     
      @data[:starting_date].to_s << '--' << @data[:ending_date].to_s 
    end

  end
end
