require Orgy.libpath(*%w[orgy org_data])

module Orgy
  # ===OrgTimeStamp
  # {org-mode time ranges}[http://orgmode.org/manual/Timestamps.html#index-ranges_002c-time-752]
  # OrgTimeStamp2will print out as an org-mode date/time. 
  class OrgTimeStamp 

    def initialize date_time
      if not date_time.class == DateTime then
        raise ArgumentError, "Argument must be a kind of DateTime"
      end
      @data = Hash.new
      @data[:date] = date_time
      @active = false
      @has_time = false
      @repeating = false
      @repeat = 'd'
      @repeat_interval = 1
    end

    def active?
      @active
    end

    def active!
      @active = true
    end

    def inactive!
      @active = false
    end

    def has_time?
      @has_time
    end

    def toggle_time!
      @has_time = !@has_time
    end

    def repeating?
      @repeating
    end

    def toggle_repeat!
      @repeating = !@repeating 
    end

    def daily!
      @repeat = 'd'
      @repeating = true
    end

    def weekly!
      @repeat = 'w'
      @repeating = true
    end

    def monthly!
      @repeat = 'm'
      @repeating = true
    end

    def yearly!
      @repeat = 'y'
      @repeating = true
    end

    def repeat_interval! num=1
      if num.class != Fixnum  and num.class != Integer then
        raise ArgumentError, "Repeat interval should be a integer value"
      end
      @repeat_interval = num
    end

    def to_s
      date = @data[:date]
      str = ""
      if active? then str << '<' else str << '[' end
      str << date.strftime("%F %a")
      if has_time? then str << date.strftime(" %R") end
      if repeating? then str << ' +' << @repeat_interval.to_s << @repeat end
      if active? then str << '>' else str << ']' end
      str
    end
    
  end
end
